part of '../../ngx_core.dart';

/// Bypasses security and trusts a given value to be safe.
@Pipe('safe')
class SafePipe implements PipeTransform {
  /// Creates a new pipe.
  SafePipe(this._sanitizer);

  /// The sanitization service.
  final DomSanitizationService _sanitizer;

  /// Trusts the specified [value] to be of safe.
  SafeValue transform(String value, [SafeValueType type = SafeValueType.html]) {
    switch (type) {
      case SafeValueType.html:
        return _sanitizer.bypassSecurityTrustHtml(value);
      case SafeValueType.resourceUrl:
        return _sanitizer.bypassSecurityTrustResourceUrl(value);
      case SafeValueType.style:
        return _sanitizer.bypassSecurityTrustStyle(value);
      case SafeValueType.url:
        return _sanitizer.bypassSecurityTrustUrl(value);
      default:
        throw ArgumentError.value(type, 'type');
    }
  }
}

/// Defines the type of trusting to apply to a safe value.
enum SafeValueType {
  /// The value is safe HTML.
  html,

  /// The value is a safe resource URL.
  resourceUrl,

  /// The value is safe CSS.
  style,

  /// The value is a safe URL.
  url
}
